//import Qt 4.7
import QtQuick 1.0

Item
{
    id: clock
    width: background.width;
    height: background.height;

    property int hours;
    property int minutes;
    property int seconds;

    property int hand_offset: 50;
    property bool night: false;
    property bool timerstarted: false

    function timeChanged()
    {
        var date = new Date;

        hours = date.getHours();

        night = (hours < 7 || hours > 19) ? true : false;

        minutes = date.getMinutes();
        seconds = date.getSeconds();

        timerstarted = true;
    }

    function timeGetStartSeconds()
    {
        timeChanged();

        return seconds * 6 - 90;
    }

    Timer
    {
        interval: 500; running: true; repeat: true;
        onTriggered: clock.timeChanged();
    }

    Image
    {
        id: background;
        source: clock.night ? "fon_night.png" : "fon_day.png";
        smooth: true;
    }

    Image
    {
        id: hour_hand;
        x: (background.width / 2) - hand_offset;
        y: (background.height / 2) - (hour_hand.height / 2);
        source: "hour.png";
        smooth: true;
        transform: Rotation
        {
            id: hourRotation;
            origin.x: hand_offset;
            origin.y: (hour_hand.height / 2);
            angle: (clock.hours * 30) + (clock.minutes * 0.5) - 90;
            Behavior on angle
            {
                RotationAnimation{ direction: RotationAnimation.Clockwise }
            }
        }
    }

    Image
    {
        id: center_big;
        anchors.centerIn: background;
        source: "center_big.png";
        smooth: true;
    }

    Image
    {
        id: minute_hand
        x: (background.width / 2) - hand_offset;
        y: (background.height / 2) - (minute_hand.height / 2);
        source: "minute.png"
        smooth: true
        transform: Rotation
        {
            id: minuteRotation
            origin.x: hand_offset;
            origin.y: (minute_hand.height / 2);
            angle: (clock.minutes * 6 ) + (clock.seconds * 0.1) - 90;
            Behavior on angle
            {
                RotationAnimation{ direction: RotationAnimation.Clockwise }
            }
        }
    }

    Image
    {
        id: center_small;
        anchors.centerIn: background;
        source: "center_small.png";
        smooth: true;
    }

    Image
    {
        id: second_hand
        x: (background.width / 2) - hand_offset;
        y: (background.height / 2) - (second_hand.height / 2);
        source: "second.png"
        smooth: true

        transform: Rotation
        {
            id: secondRotation;
            origin.x: hand_offset;
            origin.y: (second_hand.height / 2);
            angle: (timerstarted == true) ? clock.seconds * 6 - 90 : clock.timeGetStartSeconds();

            Behavior on angle
            {
                RotationAnimation{ direction: RotationAnimation.Clockwise }
            }
        }
    }
}
